import { BasicColumn, FormSchema } from '/@/components/Table';
import { render } from '/@/utils/common/renderUtils';
import { rules } from '@/utils/helper/validator';
//列表数据
export const columns: BasicColumn[] = [
  {
    title: '上架状态：0:未上架；1：已上架；默认0',
    align: 'center',
    dataIndex: 'putaway',
  },
  {
    title: '图片路径',
    align: 'center',
    dataIndex: 'images',
    customRender: render.renderImage,
  },
  {
    title: '模板价格',
    align: 'center',
    dataIndex: 'templatePrice',
  },
  {
    title: '模板标签',
    align: 'center',
    dataIndex: 'templateTags',
  },
  {
    title: '站点域名',
    align: 'center',
    dataIndex: 'domain',
  },
  {
    title: '站点备注',
    align: 'center',
    dataIndex: 'descirbe',
  },
  {
    title: '站点状态：0：创建失败，1：正常运行，2：运行异常 3:站点停止',
    align: 'center',
    dataIndex: 'runStatus',
  },
];

export const formSchema: FormSchema[] = [
  {
    label: '',
    field: 'id',
    component: 'Input',
    show: false,
  },
  {
    label: '模板名称',
    field: 'name',
    component: 'Input',
    required: true,
  },
  {
    label: '图片路径',
    field: 'images',
    required: true,
    component: 'JImageUpload',
    componentProps: {
      fileMax: 1,
    },
  },
  {
    label: '站点code',
    field: 'code',
    component: 'Input',
    dynamicDisabled: ({ values }) => {
      return !!values.code && !!values.id;
    },
    dynamicRules: ({ model, schema }) => {
      return [{ ...rules.exsitCheckRule('adweb_site', 'code', model, schema, false, '该临时站点不存在')[0], trigger: 'blur' }];
    },
  },
  {
    label: '域名',
    field: 'domain',
    component: 'Input',
    dynamicDisabled: ({ values }) => {
      return !!values.id;
    },
    ifShow: ({ values }) => {
      return !!values.domain;
    },
  },
];
